@@ -1360,7 +1360,7 @@ class Builder(Update):
             if path.exists(dbPkg) and path.exists(pkgDir):
                 # get pkg list from distro
                 pkgList = reduce(lambda x, y: x + y,
-                    [[path.join(dbPkg, x, z) for z 
+                    [[path.join(x, "%s.tbz2" % z) for z
                         in os.listdir(path.join(dbPkg, x))] for x 
                             in os.listdir(dbPkg)],  
                     [])
@@ -1373,20 +1373,7 @@ class Builder(Update):
                         if path.isdir(z))],
                     [])
                 # remove files which in binary and not in db/pkg
-                removeList = []
-                for binPkg in binList:
-                    # Удаляем расширения файлов, чтобы получить базовые имена
-                    pkgName = path.splitext(binPkg)[0]
-                    tbz2 = f"{pkgName}.tbz2"
-                    gpkg = f"{pkgName}.gpkg.tar"
-                    # Сравниваем имена пакетов
-                    if pkgName in pkgList:
-                        # Приоритет у gpkg, удаляем tbz2 при наличии обоих
-                        if tbz2 in binList and gpkg in binList:
-                            removeList.append(tbz2)
-                    else:
-                        removeList.append(binPkg)
-
+                removeList = list(set(binList) - set(pkgList))
 
                 if removeList:
                     removelist_str = ",".join(
