@@ -196,35 +196,35 @@ class ClBuilderUpdateAction(Action):
                      Get('update.cl_update_pretend_set') == 'off' and
                      Get('update.cl_update_sync_only_set') == 'off')
                  },
-                {'name': 'update_other:group_changed_packages',
-                 'group': __("Rebuild modified packages"),
-                 'tasks': [
-                     {'name': 'changed_packages',
-                      'message': __("Calculating dependencies"),
-                      'method': 'Builder.rebuild_changed_packages('
-                                'cl_builder_path,'
-                                'cl_builder_repository_data)',
-                      'condition': lambda Get:
-                      Get('cl_builder_rebuild_changed_set') == 'on'
-                      }
-                 ]
-                 },
-                {'name': 'update_other:update_perl',
-                 'group': __("Updating Perl modules"),
-                 'tasks': [
-                     {'name': 'perl_cleaner',
-                      'message': __(
-                          'Find & rebuild packages and Perl header files '
-                          'broken due to a perl upgrade'),
-                      'method': 'Builder.chroot_emergelike(cl_builder_path,'
-                                '"perl-cleaner","all")',
-                      'condition': BuilderConditions.was_installed(
-                          'dev-lang/perl$', EmergeMark.PerlCleaner),
-                      'decoration': 'Builder.update_task("%s")'
-                                    % EmergeMark.PerlCleaner
-                      },
-                 ]
-                 },
+                # {'name': 'update_other:group_changed_packages',
+                #  'group': __("Rebuild modified packages"),
+                #  'tasks': [
+                #      {'name': 'changed_packages',
+                #       'message': __("Calculating dependencies"),
+                #       'method': 'Builder.rebuild_changed_packages('
+                #                 'cl_builder_path,'
+                #                 'cl_builder_repository_data)',
+                #       'condition': lambda Get:
+                #       Get('cl_builder_rebuild_changed_set') == 'on'
+                #       }
+                #  ]
+                #  },
+                # {'name': 'update_other:update_perl',
+                #  'group': __("Updating Perl modules"),
+                #  'tasks': [
+                #      {'name': 'perl_cleaner',
+                #       'message': __(
+                #           'Find & rebuild packages and Perl header files '
+                #           'broken due to a perl upgrade'),
+                #       'method': 'Builder.chroot_emergelike(cl_builder_path,'
+                #                 '"perl-cleaner","all")',
+                #       'condition': BuilderConditions.was_installed(
+                #           'dev-lang/perl$', EmergeMark.PerlCleaner),
+                #       'decoration': 'Builder.update_task("%s")'
+                #                     % EmergeMark.PerlCleaner
+                #       },
+                #  ]
+                #  },
                 {'name': 'update_other:depclean',
                  'group': __("Cleaning the system from needless packages"),
                  'tasks': [
